affects(ant)
ant (as "antecedent") is some DexiAttribute.
The function returns TRUE if ant lies on the path leading from this attribute
towards the root, and is therefore affected by this attribute.
count()
Return the number of inputs of this attribute.
dim()
Dimensions of the value space determined by this attribute's inputs.
Result: a numeric vector of length equal to ninp(), containing DexiScale$count() of
all descendant attributes, or NA for attributes without associated scales.
For basic attributes, dim() returns NULL.
initialize(
name = "",
description = "",
inputs = list(),
id = "",
link = NULL,
scale = NULL,
funct = NULL,
parent = NULL,
...
)
Initialize a DexiAttribute object.
inp_index(inp)
Return the index of attribute inp in inputs of this attribute.
is_aggregate()
Logical: TRUE for aggregate attributes (attributes whose ninp() > 0).
is_basic(include_linked = TRUE)
Logical: TRUE for basic attributes (attributes whose ninp() == 0.
include_linked determines whether linked attributes are counted as basic
(TRUE) or not (FALSE).
is_continuous()
Logical: Indicates whether or not this is a continuous attribute.
is_discrete()
Logical: Indicates whether or not this is a discrete attribute.
is_link()
Logical: Indicates whether or not this is a linked attribute.
level()
Return the level of this attribute in the hierarchy.
The level of DexiModel$root is 0.
model()
Return the DexiModel that contains this attribute.
ninp()
Return the number of inputs of this attribute.
structure()
Make an indentation string for this attribute, used for printing it in show().
tree_indent(none = " ", thru = "|", link = "*", last = "+", line = "-")
Construct a string for representing the indentation of this attribute in the model structure.
The arguments none, thru, link, last and line are
character strings to be used in the construction.
verify()
Check the correctnes of a DexiAttribute object and its fields. Result: error() or TRUE.