- model
A DexiModel object. Required.
- alternatives
A data.frame of alternatives (normally an output of evaluate()) or
indices to model$alternatives. The default value NULL selects model$alternatives.
- interpret
character(1). Determines how the original values in alternatives are
interpreted, i.e., converted prior to submitting them to aggregate():
"set"
As a set of values. Any distribution-type value is converted to a set,
thus discarding the numeric membership information.
"distribution"
As a value distribution, i.e., a numeric vector of membership values.
"none"
No conversion.
Values corresponding to continuous attributes are not converted nor affected by these settings.
aggregate
A function accepting the interpreted DEXi value (see interpret) and converting
it to become part of the output data frame. Normally, this function is assumed to accept
a numeric vector argument and aggregate it in a single numeric value.
The default aggregation function is min(). Typical alternatives include max() and mean().
omin
numeric(1). Lower bound of the output value interval (see map_values). Default: 0.
omax
numeric(1). Upper bound of the output value interval (see map_values). Default: 1.
map_values
logical(1). When TRUE, values produced by aggregate() are further scaled
to the interval [omin:omax]. Input bounds are determined from
the corresponding attribute scales (for discrete attributes) or
as minimum/maximum values from alternatives (for continuous attributes).
reverse_descending
logical(1). Whether or not to reverse the values of attributes
whose scales are of a "descending" preference order.
verbatim
character(). Names of alternatives' data columns
that are included in the output without conversion. Default: "name".
skip
character(). Names of alternatives' data columns
that are ignored in the process. Default: NULL.
continuous
A function converting a data column that corresponds to a continuous attribute.
Default: convert_data_continuous().
Setting continuous to NULL excludes all continuous attributes from conversion.
discrete
A function converting a data column that corresponds to a discrete attribute.
Default: convert_data_discrete().
Setting discrete to NULL excludes all discrete attributes from conversion.